from django.contrib.auth.decorators import login_required
from django.contrib.auth.views import LogoutView
from django.urls import path, include, re_path
from django_spaghetti.views import Plate
from rest_framework import routers
from schema_graph.views import Schema

from sharix_admin.apiviews import *
from sharix_admin.views import *

router = routers.SimpleRouter()
router.register(r'sharix-users', SharixUserMVS)
router.register(r'group', GroupMVS)

app_name = "sharix_admin"

urlpatterns = [
    # Регистрация / Вход / Выход
    path('auth/signup/', ShariXSignUpView.as_view(), name="auth_signup"),
    path('auth/login/', ShariXLoginView.as_view(), name='auth_login'),
    path('auth/logout/', login_required(LogoutView.as_view()), name="auth_logout"),
    path('auth/reset-password/', ShariXResetPasswordView.as_view(), name='auth_reset_password'),

    # Главная
    path('', login_required(MainView.as_view()), name='main'),

    # --- Ниже страницы, требующие ревью ---

    path('transactions/', login_required(TransactionsView.as_view()), name='transactions'),
    path('payment/', login_required(PaymentView.as_view()), name='payment'),

    # Страница "Сотрудничество" (запрос на подключение к сервису)
    path('cooperate/', login_required(CooperateView.as_view()), name='cooperate'),

    # Страница "О партнере"
    path('partner/', login_required(PartnerDetailView.as_view()), name='partner_detail'),
    path('partner/edit/', login_required(PartnerEditView.as_view()), name='partner_edit'),
    path('partner/doc/<str:doc_code>/upload', login_required(PartnerDocUploadView.as_view()),
         name='partner_doc_upload'),
    path('partner/doc/<str:doc_code>', login_required(PartnerDocView.as_view()), name='partner_doc'),

    path('transactions/<int:trans_id>/', trans_id, name='transid'),
    path('balance/', balance, name='balance'),

    path('partners/', login_required(PartnersListView.as_view()), name='partners'),
    path('partners/change_status/', change_partners_status, name='partners/change_status'),

    path('resource/', login_required(ResourceListView.as_view()), name='resource'),
    path('resource/change_status/', change_resource_status, name='resource/change_status'),

    path('provider/', login_required(ProviderListView.as_view()), name='provider'),
    path('provider/change_status/', change_provider_status, name='provider/change_status'),

    path('service_tariff/', login_required(ServiceTariffListView.as_view()), name='service_tariff'),
    path('service_tariff/add/', login_required(ServiceTariffCreate.as_view()), name='service_tariff/add/'),
    path('service_tariff/edit/<int:pk>', login_required(ServiceTariffUpdateView.as_view()),
         name='service_tariff/edit/'),

    path('service_category/', login_required(ServiceCategoryListView.as_view()), name='service_category'),
    path('service_category/edit/<int:pk>', login_required(ServiceCategoryUpdateView.as_view()), name='service_category/edit/'),
    path('service_category/add/', login_required(ServiceCategoryCreate.as_view()), name='service_category/add/'),
    path('service_category/delete/<int:pk>', login_required(ServiceCategoryDelete.as_view()), name='service_category/delete/'),

    path('service_information/add/', login_required(ServiceInformationCreate.as_view()),
         name='service_information-add'),
    path('service_information/edit/<int:pk>', login_required(ServiceInformationUpdateView.as_view()),
         name='service_information/edit/'),

    path('service/', ServiceListView.as_view(), name='service'),
    path('service/change_status/', change_service_status, name='service/change_status'),

    # path('partner_information/', login_required(PartnerInfoView.as_view()), name='partner_information/'),
    # path('partner_information/add/', login_required(PartnerInformationCreate.as_view()), name='partner_information/add/'),
    # path('partner_information/edit/<int:pk>', login_required(PartnerInformationUpdateView.as_view()), name='partner_information/edit/'),

    path('user_information', login_required(UserListView.as_view()), name='user_information'),

    path('api/v1/auth/', include('djoser.urls.authtoken'), name="api-auth"),
    path('api/v1/platform/', include(router.urls), name="api-platform"),
    path('by_phone/<phone_number>/', get_user_by_phone_number, name='get_user_by_phone_number'),

    path('senderphone/', PhoneSender.as_view()),

    # schemas
    path('schemav1/', login_required(Schema.as_view()), name='schemav1'),
    path('schemav2/', login_required(Plate.as_view()), name='schemav2'),
    path('schemav3/', schema_v3, name='schema'),

    re_path(r'^redoc/$', schema_view.with_ui('redoc', cache_timeout=0), name='schema-redoc'),
]
